.. py:module:: PIL.ImageCms
.. py:currentmodule:: PIL.ImageCms

:py:mod:`ImageCms` Module
=========================

The :py:mod:`ImageCms` module provides color profile management
support using the LittleCMS2 color management engine, based on Kevin
Cazabon's PyCMS library.

.. automodule:: PIL.ImageCms
    :members:
    :noindex:
